@@ -1,5 +1,25 @@
+#!/usr/bin/perl
+
 use strict;
 
+#This util generates a graph of all the levels in the levels folder.
+#run using "perl utils/graph-levels.pl | dot -Tpng > out.png" in the root frogatto folder. Outputs to out.png to cwd.
+
+# appending --show_music after utils/graph-levels.pl will write the song used in each level, under the level's name
+
+my $show_music = 0;
+
+while(my $arg = shift @ARGV) {
+	if($arg eq '--show_music') {
+		$show_music = 1;
+	} else {
+		die "Unrecognized argument: $arg";
+	}
+}
+
+
+
+
 my @levels = glob("data/level/*");
 
 my %index = ();
@@ -20,6 +40,7 @@ foreach my $level (@levels) {
 
 	my $door = '';
 	my $saves = 0;
+	my $music = '';
 
 	while(my $line = <LVL>) {
 		if(my ($toilet) = $line =~ /type="(save_toilet|dungeon_save_door)"/) {
@@ -30,6 +51,10 @@ foreach my $level (@levels) {
 			$door = $label;
 		}
 
+		if(my ($song_name) = $line =~ /music="(.*)"/) {
+			$music = $song_name;
+		}
+
 		if(my ($next_level) = $line =~ /next_level="(.*)"/) {
 			push @adj, [$level, $next_level, 'next_level'];
 		}
@@ -48,6 +73,10 @@ foreach my $level (@levels) {
 	my $label = $level;
 	$label .= " (save)" if $saves == 1;
 	$label .= " ($saves saves)" if $saves > 1;
+	if($show_music){
+		$label .= "\\n";
+		$label .= $music;
+	}
 
 	print qq~N$index [label="$label",shape=box,fontsize=12];\n~;
 
